<?php

class WPBakeryShortCode_Tt_Portfolio extends WPBakeryShortCode {
    protected function content( $atts, $content = null){
        extract(shortcode_atts(array(
            'title' => 'Latest works',
            'column' => '5',
            'count' => '20',
            'filter' => 'no',
            'categories' => ''
        ), $atts));


        // build category ids
        $cats = array();
        if( !empty($categories) ){
            $exps = explode(",", $categories);
            foreach($exps as $val){
                if( (int)$val>-1 ){
                    $cats[]=(int)$val;
                }
            }
        }


        // build query
        $args = array(
                        'post_type' => 'portfolio',
                        'posts_per_page' => $count,
                        'ignore_sticky_posts' => true
                    );
        if(!empty($cats)){
            $args['tax_query'] = array(
                                    'relation' => 'IN',
                                    array(
                                        'taxonomy' => 'portfolio_entries',
                                        'field' => 'id',
                                        'terms' => $cats
                                    )
                                );
        }

        
        $filter_html = '';
        $cat_array = array();
        $items = '';
        $encoded_args =  serialize($args) ;

        $posts_query = new WP_Query($args);
        while ( $posts_query->have_posts() ) {
            $posts_query->the_post();

            $img = '';
            $img_full = '';
            if( has_post_thumbnail() ){

                $img = wp_get_attachment_image_src( get_post_thumbnail_id( get_the_ID() ), 'nrgfashion-project-img' );
                $img_full = wp_get_attachment_image_src( get_post_thumbnail_id( get_the_ID() ), 'full' );
                $img = !empty($img) ? $img[0] : '';
                $img_full = !empty($img_full) ? $img_full[0] : '';
            }


            $cats = '';
            $cat_titles = array();
            $terms = wp_get_post_terms(get_the_ID(), 'portfolio_entries');
            foreach ($terms as $term){
                $cat_title = $term->name;
                $cat_slug = $term->slug;

                $cat_titles []= $cat_title;
                if( $filter=='yes' && !in_array($term->term_id, $cat_array) ){
                    $filter_html .= "<button class='button' data-filter='.ftr-$cat_slug'>$cat_title</button>";
                    $cat_array[] = $term->term_id;
                }

                $cats .= "ftr-$cat_slug ";
            }


            $items .= "<div class='work-img $cats' data-category='$cats'>
                            <div class='gallery-border'>
                                <img src='$img' alt='picture'>
                            </div>
                            <div class='girl-laugh'>
                                <h6>".get_the_title()."</h6>
                                <p>".implode(', ', $cat_titles)."</p>
                            </div>
                        </div>";
        }
        // reset query
        wp_reset_postdata();

        if( $filter=='yes' ){

            $filter_html = "<div id='filters' class='corner-stamp work-img '>
                                <div class='filter-container'>
                                    <button class='button actual' data-filter='*'>".__('all', 'nrgfashion')."</button>
                                    $filter_html
                                </div>
                            </div>";
        }
            return "<div class='fashion-gallery' data-column='$column'>
                        <div class='container-fluid'>
                            <div class='row' >
                                <div class='isotope allmenu'>
                                    <div class='grid'></div>
                                    $filter_html
                                    $items
                                </div>
                            </div>
                        </div>
                    </div>";
    }
}

vc_map( array(
    "name" => esc_html__( 'Portfolio', 'nrgfashion' ),
    "description" => esc_html__("post type: portfolio", 'nrgfashion'),
    "base" => 'tt_portfolio',
    "icon" => "tt-icon portfolio",
    "content_element" => true,
    "category" => esc_html__('NRGFashion', 'nrgfashion'),
    'params' => array(
        array(
            "type" => 'textfield',
            "param_name" => "title",
            "heading" => esc_html__("Title", 'nrgfashion'),
            "value" => 'Latest works',
            "holder" => 'div'
        ),
        array(
            "type" => "dropdown",
            "param_name" => "column",
            "heading" => esc_html__("Column", 'nrgfashion'),
            "value" => array(
                "1 column" => "1",
                "2 columns" => "2",
                "3 columns" => "3",
                "4 columns" => "4",
                "5 columns" => "5",
                "6 columns" => "6"
            ),
            "std" => "5"
        ),
        array(
            "type" => 'textfield',
            "param_name" => "count",
            "heading" => esc_html__("Count (posts per page)", 'nrgfashion'),
            "value" => '20'
        ),
        array(
            "type" => "dropdown",
            "param_name" => "filter",
            "heading" => esc_html__("Show Filter", 'nrgfashion'),
            "value" => array(
                "No" => "no",
                "Yes" => "yes"
            ),
            "std" => "no"
        ),
        // array(
        //     "type" => "dropdown",
        //     "param_name" => "load_more",
        //     "heading" => esc_html__("Show Ajax Pager", 'nrgfashion'),
        //     "value" => array(
        //         "No" => "no",
        //         "Yes" => "yes"
        //     ),
        //     "std" => "no"
        // ),
        array(
            "type" => 'textfield',
            "param_name" => "categories",
            "heading" => esc_html__("Categories", 'nrgfashion'),
            "description" => esc_html__("Specify category ID (multiple IDs with comma) or leave blank to display items from all categories.", 'nrgfashion'),
            "value" => ''
        )
    )
));




add_action('wp_ajax_tt_portfolio_posts', 'tt_portfolio_posts_hook');
add_action('wp_ajax_nopriv_tt_portfolio_posts', 'tt_portfolio_posts_hook');

function tt_portfolio_posts_hook(){
    $encoded_args = $_POST['folio_args'];
    $pager = $_POST['pager'];
    $args = unserialize( $encoded_args );

    $args['paged'] = $pager;

    $posts_query = new WP_Query($args);
    if( $posts_query->have_posts() ){
        
        $items = '';
        $filter_html = '';
        $cat_array = array();

        while ( $posts_query->have_posts() ) {
            $posts_query->the_post();

            $img = '';
            $img_full = '';
            if( has_post_thumbnail() ){
                $img = wp_get_attachment_image_src( get_post_thumbnail_id( get_the_ID() ), 'folio-thumb' );
                $img_full = wp_get_attachment_image_src( get_post_thumbnail_id( get_the_ID() ), 'full' );
                $img = !empty($img) ? $img[0] : '';
                $img_full = !empty($img_full) ? $img_full[0] : '';
            }


            $cats = '';
            $cat_titles = array();
            $terms = wp_get_post_terms(get_the_ID(), 'portfolio_entries');
            foreach ($terms as $term){
                $cat_title = $term->name;
                $cat_slug = $term->slug;

                $cat_titles []= $cat_title;
                if( !in_array($term->term_id, $cat_array) ){
                    $filter_html .= "<li data-value='ftr-$cat_slug'><a href='javascript:;'>$cat_title</a></li>";
                    $cat_array[] = $term->term_id;
                }

                $cats .= "ftr-$cat_slug ";
            }

            $items .= '<li class="'.$cats.'">
                            <div class="portfolio-image-block">
                                <a title="Portfolio image" href="'.get_permalink().'"><img src="'.$img.'" alt="portfolio image 1"></a>
                                <div class="portfolio-block-hover">
                                    <a title="'.esc_attr(get_the_title()).'" href="'.get_permalink().'" class="portfolio-title">'.get_the_title().'</a>
                                    <p>'.implode(', ', $cat_titles).'</p>
                                    <hr>
                                    <div class="zoom-link">
                                        <a title="Search Icon" href="'.$img_full.'"><i class="fa fa-search"></i></a>
                                        <a title="Link" href="'.get_permalink().'"><i class="fa fa-link"></i></a>
                                    </div>
                                </div>
                            </div>
                        </li>';
        }

        echo json_encode( array(
                'result' => '1',
                'folio'  => $items,
                'filter' => $filter_html,
                'args'  => serialize($args)
            ) );
    }
    else{
        echo json_encode( array('result' => '0') );
        exit;
    }
    
    
    exit;
}
